#include "mainwindow.h"
#include "ui_mainwindow.h"

#include <QToolBar>
#include <QToolButton>
#include <QFileDialog>
#include <QMessageBox>
#include <QUndoStack>
#include <QMenu>
#include <QKeySequence>
#include <QHBoxLayout>
#include <QVBoxLayout>
#include <QTimer>
#include <QScrollBar>
#include <QColorDialog>
#include <QStyleOptionToolButton>
#include "chmiaboutdlg.h"

MainWindow::MainWindow(QWidget *parent)
    : QMainWindow(parent)
{
    m_paintView = new PaintView(this);
    m_scrollArea = new QScrollArea(this);
    // 创建标尺
    m_hRuler = new RulerWidget(RulerWidget::Horizontal);
    m_vRuler = new RulerWidget(RulerWidget::Vertical);

    // 标尺样式设置
    m_hRuler->setFixedHeight(30);
    m_vRuler->setFixedWidth(30);
    //m_hRuler->setUnitSystem(true);  // 使用公制单位
    //m_vRuler->setUnitSystem(true);

    m_paintView->m_hRuler = m_hRuler;
    m_paintView->m_vRuler = m_vRuler;

    // 配置滚动区域
    m_scrollArea->setWidget(m_paintView);
    m_scrollArea->setWidgetResizable(true);
    m_scrollArea->setFrameShape(QFrame::NoFrame);


    // 主布局
    QWidget *centralWidget = new QWidget;
    QGridLayout *mainLayout = new QGridLayout(centralWidget);
    mainLayout->setSpacing(0);
    mainLayout->setContentsMargins(0, 0, 0, 0);

    mainLayout->addWidget(m_hRuler, 0, 1);
    mainLayout->addWidget(m_vRuler, 1, 0);
    mainLayout->addWidget(m_scrollArea, 1, 1);

    setCentralWidget(centralWidget);

    // 信号连接
    connectSignals();

    // 初始更新
    QTimer::singleShot(0, this, &MainWindow::updateRulers);

    //setCentralWidget(m_paintView);
    createActions();
    createToolBar();
    CreateLineBar();
    CreateFirstBar();
    createColorToolBar();
    CreateSecondBar();
    createColorToolBar2();
    updateActions();

    connect(m_paintView, &PaintView::scaleChanged,
            this, &MainWindow::updateActions);

    setWindowTitle(tr("UCanCode Pixmap Editor"));
    // 设置窗口最小尺寸
    setMinimumSize(200, 150);

    // 设置窗口最大尺寸（设为 QWIDGETSIZE_MAX 表示无限制）
    setMaximumSize(QWIDGETSIZE_MAX, QWIDGETSIZE_MAX);

    // 设置窗口部件的尺寸策略
    setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
    // 或使用更灵活的扩展策略
    setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
}

void MainWindow::SetLineWidth(int value)
{
    m_paintView->setBrushSize(value);
}

void MainWindow::CreateLineBar() {
    QToolBar *colorBar = addToolBar("Line Width");
    LineWidthToolButton *btn = new LineWidthToolButton;

    // 设置紧凑按钮属性
    // btn->setFixedSize(BUTTON_SIZE, BUTTON_SIZE);
    // btn->setIconSize(QSize(ICON_SIZE, ICON_SIZE));
    btn->setAutoRaise(true);  // 紧凑模式
    colorBar->addWidget(btn);
    colorBar->setFixedWidth(64);
    connect(btn, &LineWidthToolButton::lineWidthChanged,
            this, &MainWindow::SetLineWidth);
    mpLineWidth = btn;
}

void MainWindow::CreateFirstBar() {
    QToolBar *colorBar = addToolBar("Back Color");
    ColorToolButton *btn = new ColorToolButton;

    // 设置紧凑按钮属性
   // btn->setFixedSize(BUTTON_SIZE, BUTTON_SIZE);
   // btn->setIconSize(QSize(ICON_SIZE, ICON_SIZE));
    btn->setAutoRaise(true);  // 紧凑模式
    btn->setDisplayText("背景");

    colorBar->addWidget(btn);
    colorBar->setFixedWidth(110);

    mpColorBack = btn;
}

void MainWindow::CreateSecondBar() {
    QToolBar *colorBar = addToolBar("Fore Color");
    ColorToolButton *btn = new ColorToolButton;

    // 设置紧凑按钮属性
    // btn->setFixedSize(BUTTON_SIZE, BUTTON_SIZE);
    // btn->setIconSize(QSize(ICON_SIZE, ICON_SIZE));
    btn->setAutoRaise(true);  // 紧凑模式
    btn->setDisplayText("前景");

    colorBar->addWidget(btn);
    colorBar->setFixedWidth(110);

    mpColorFore = btn;
}

void MainWindow::createColorToolBar() {
    QToolBar *colorBar = addToolBar("Colors");
    colorBar->setOrientation(Qt::Vertical);
    colorBar->setToolButtonStyle(Qt::ToolButtonIconOnly);

    // 创建紧凑颜色网格
    QWidget *colorGridWidget = new QWidget;
    QGridLayout *colorLayout = new QGridLayout(colorGridWidget);
    colorLayout->setSpacing(1);  // 最小间距
    colorLayout->setContentsMargins(1, 1, 1, 1);  // 最小边距

    // 生成30种颜色（3行×10列）
    QList<QColor> colors;
    for (int h = 0; h < 360; h += 36) {  // 10种色调
        colors.append(QColor::fromHsv(h, 255, 255));       // 高饱和度
        colors.append(QColor::fromHsv(h, 255, 128));       // 中等亮度
        colors.append(QColor::fromHsv(h, 128, 255));       // 低饱和度
    }

    // 创建紧凑颜色按钮
    int index = 0;
    const int BUTTON_SIZE = 20;  // 按钮尺寸
    const int ICON_SIZE = 16;    // 图标尺寸

    for (int row = 0; row < 3; ++row)
    {
        for (int col = 0; col < 10; ++col)
        {
            if (index >= colors.size()) break;

            QColor color = colors[index++];
            QToolButton *btn = new QToolButton;

            // 设置紧凑按钮属性
            btn->setFixedSize(BUTTON_SIZE, BUTTON_SIZE);
            btn->setIconSize(QSize(ICON_SIZE, ICON_SIZE));
            btn->setAutoRaise(true);  // 紧凑模式

            // 颜色显示
            QPixmap pix(ICON_SIZE, ICON_SIZE);
            pix.fill(color);
            btn->setIcon(pix);

            // 紧凑型悬停效果
            btn->setStyleSheet(QString(
                                   "QToolButton { border: 1px solid #d0d0d0; }"
                                   "QToolButton:hover { border: 1px solid %1; }"
                                   ).arg(color.darker(150).name()));

            connect(btn, &QToolButton::clicked, [this, color] {
                if(mpColorBack)
                    {
                    mpColorBack->setColor(color);

                }

                m_paintView->setBackgroundColor(color);
              //  m_paintArea->setColor(color);
            });

            colorLayout->addWidget(btn, row, col);
        }
    }

    // 添加更多颜色按钮（单独一行）
    QToolButton *moreBtn = new QToolButton;
    moreBtn->setText("+");
    moreBtn->setToolTip("Custom Color");
    moreBtn->setFixedSize(BUTTON_SIZE, BUTTON_SIZE);
    moreBtn->setStyleSheet(
        "QToolButton { border:1px solid #a0a0a0; font:bold 9pt; color:#606060; }"
        "QToolButton:hover { border-color:#FFA500; color:#FFA500; }"
        );
    connect(moreBtn, &QToolButton::clicked, [this] {
        QColor color = QColorDialog::getColor();
        if(mpColorBack)
        {
            mpColorBack->setColor(color);
        }
        m_paintView->setBackgroundColor(color);
       // if (color.isValid()) m_paintArea->setColor(color);
    });
    colorLayout->addWidget(moreBtn, 3, 0, 1, 10);  // 跨列显示

    // 应用紧凑布局
    colorBar->addWidget(colorGridWidget);

    colorBar->setStyleSheet(
        "QToolBar { background:#f8f8f8; padding:0; }"
        "QToolButton { margin:0; padding:0; }"
        );

    // 设置工具栏属性
    colorBar->setIconSize(QSize(ICON_SIZE, ICON_SIZE));
    colorBar->setMinimumWidth(BUTTON_SIZE * 10 + 4);  // 10个按钮宽度
    colorBar->setFixedWidth(BUTTON_SIZE * 10 + 4);
}

void MainWindow::createColorToolBar2() {
    QToolBar *colorBar = addToolBar("Colors");
    colorBar->setOrientation(Qt::Vertical);
    colorBar->setToolButtonStyle(Qt::ToolButtonIconOnly);

    // 创建紧凑颜色网格
    QWidget *colorGridWidget = new QWidget;
    QGridLayout *colorLayout = new QGridLayout(colorGridWidget);
    colorLayout->setSpacing(1);  // 最小间距
    colorLayout->setContentsMargins(1, 1, 1, 1);  // 最小边距

    // 生成30种颜色（3行×10列）
    QList<QColor> colors;
    for (int h = 0; h < 360; h += 36) {  // 10种色调
        colors.append(QColor::fromHsv(h, 255, 255));       // 高饱和度
        colors.append(QColor::fromHsv(h, 255, 128));       // 中等亮度
        colors.append(QColor::fromHsv(h, 128, 255));       // 低饱和度
    }

    // 创建紧凑颜色按钮
    int index = 0;
    const int BUTTON_SIZE = 20;  // 按钮尺寸
    const int ICON_SIZE = 16;    // 图标尺寸

    for (int row = 0; row < 3; ++row) {
        for (int col = 0; col < 10; ++col) {
            if (index >= colors.size()) break;

            QColor color = colors[index++];
            QToolButton *btn = new QToolButton;

            // 设置紧凑按钮属性
            btn->setFixedSize(BUTTON_SIZE, BUTTON_SIZE);
            btn->setIconSize(QSize(ICON_SIZE, ICON_SIZE));
            btn->setAutoRaise(true);  // 紧凑模式

            // 颜色显示
            QPixmap pix(ICON_SIZE, ICON_SIZE);
            pix.fill(color);
            btn->setIcon(pix);

            // 紧凑型悬停效果
            btn->setStyleSheet(QString(
                                   "QToolButton { border: 1px solid #d0d0d0; }"
                                   "QToolButton:hover { border: 1px solid %1; }"
                                   ).arg(color.darker(150).name()));

            connect(btn, &QToolButton::clicked, [this, color] {
                if(mpColorFore)
                {
                    mpColorFore->setColor(color);
                }
                m_paintView->setForegroundColor(color);
            });

            colorLayout->addWidget(btn, row, col);
        }
    }

    // 添加更多颜色按钮（单独一行）
    QToolButton *moreBtn = new QToolButton;
    moreBtn->setText("+");
    moreBtn->setToolTip("Custom Color");
    moreBtn->setFixedSize(BUTTON_SIZE, BUTTON_SIZE);
    moreBtn->setStyleSheet(
        "QToolButton { border:1px solid #a0a0a0; font:bold 9pt; color:#606060; }"
        "QToolButton:hover { border-color:#FFA500; color:#FFA500; }"
        );
    connect(moreBtn, &QToolButton::clicked, [this] {
        QColor color = QColorDialog::getColor();
        if(mpColorFore)
        {
            mpColorFore->setColor(color);
        }

        m_paintView->setForegroundColor(color);
        // if (color.isValid()) m_paintArea->setColor(color);
    });
    colorLayout->addWidget(moreBtn, 3, 0, 1, 10);  // 跨列显示

    // 应用紧凑布局
    colorBar->addWidget(colorGridWidget);

    colorBar->setStyleSheet(
        "QToolBar { background:#f8f8f8; padding:0; }"
        "QToolButton { margin:0; padding:0; }"
        );

    // 设置工具栏属性
    colorBar->setIconSize(QSize(ICON_SIZE, ICON_SIZE));
    colorBar->setMinimumWidth(BUTTON_SIZE * 10 + 4);  // 10个按钮宽度
    colorBar->setFixedWidth(BUTTON_SIZE * 10 + 4);
}

void MainWindow::connectSignals()
{


    // // 视口变化同步
    // connect(m_scrollArea->horizontalScrollBar(), &QScrollBar::valueChanged,
    //         this, &MainWindow::updateRulers);
    // connect(m_scrollArea->verticalScrollBar(), &QScrollBar::valueChanged,
    //         this, &MainWindow::updateRulers);

    // 鼠标位置同步
    // connect(m_paintView, &PaintView::mousePositionChanged, this, [=](QPointF pos) {
    //     m_hRuler->setMousePosition(pos.x());
    //     m_vRuler->setMousePosition(pos.y());
    // });

    // // 窗口大小变化更新
    // connect(m_scrollArea->viewport(), &QWidget::geometryChanged,
    //         this, &MainWindow::updateRulers);
}

void MainWindow::updateRulers()
{
    // 计算视口偏移量
    const QPoint scrollOffset(
        m_scrollArea->horizontalScrollBar()->value(),
        m_scrollArea->verticalScrollBar()->value()
        );

    // 计算实际标尺原点
    const qreal originX = scrollOffset.x() / m_paintView->m_scaleFactor;
    const qreal originY = scrollOffset.y() / m_paintView->m_scaleFactor;

    // 更新标尺参数
    m_hRuler->setOriginOffset(originX);
    m_vRuler->setOriginOffset(originY);

    // 更新标尺尺寸
    const QSize viewportSize = m_scrollArea->viewport()->size();
    m_hRuler->setMinimumWidth(viewportSize.width());
    m_vRuler->setMinimumHeight(viewportSize.height());
}

void MainWindow::createActions()
{
    // 文件操作
    QAction *openAct = new QAction(tr("打开..."), this);
    openAct->setShortcut(QKeySequence::Open);
    connect(openAct, &QAction::triggered, this, &MainWindow::open);

    QAction *saveAct = new QAction(tr("保存..."), this);
    saveAct->setShortcut(QKeySequence::Save);
    connect(saveAct, &QAction::triggered, this, &MainWindow::save);

    QAction *exitAct = new QAction(tr("退出"), this);
    exitAct->setShortcut(QKeySequence::Quit);
    connect(exitAct, &QAction::triggered, this, &QWidget::close);

    actClear = new QAction(tr("清除"), this);
    connect(actClear, &QAction::triggered, this, &MainWindow::clearback);

    // 缩放
    actAbout = new QAction(tr("关于DrawPad"), this);

    connect(actAbout, &QAction::triggered, this, &MainWindow::About);

    // 添加到菜单
    QMenu *fileMenu = menuBar()->addMenu(tr("文件"));
    fileMenu->addAction(openAct);
    fileMenu->addAction(saveAct);
    fileMenu->addSeparator();
    fileMenu->addAction(exitAct);

    QMenu *editMenu = menuBar()->addMenu(tr("编辑"));
   // editMenu->addAction(m_undoAction);
   // editMenu->addAction(m_redoAction);
    editMenu->addAction(actClear);

    QMenu *viewMenu = menuBar()->addMenu(tr("关于"));
    viewMenu->addAction(actAbout);

}

void MainWindow::createToolBar()
{
    QToolBar *toolBar = addToolBar(tr("Tools"));
    toolBar->setIconSize(QSize(24,24));

    const QList<QPair<ToolType, QString>> tools = {
        {Point, ":/icons/point.png"},
        {Line, ":/icons/line.png"},
        {Rectangle, ":/icons/rect.png"},
        {Ellipse, ":/icons/ellipse.png"},
        {Text, ":/icons/text.png"}
    };

    QToolButton *cursorBtn = new QToolButton;
    cursorBtn->setIcon(QIcon(":/images/pointer.png"));
    cursorBtn->setCheckable(true);
    cursorBtn->setChecked(true);
    cursorBtn->setText("无");
    cursorBtn->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
    connect(cursorBtn, &QToolButton::clicked,this, &MainWindow::oncursor);
    toolBar->addWidget(cursorBtn);
    m_toolButtons[Cursor] = cursorBtn;

    if(1)
    {
        QToolButton *btn = new QToolButton;
        btn->setIcon(QIcon(":/images/pc_screenshot_pen_click.png"));
        btn->setCheckable(true);
        btn->setText("笔");
        btn->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
        connect(btn, &QToolButton::clicked,this, &MainWindow::onpen);

        toolBar->addWidget(btn);
        m_toolButtons[Pen] = btn;
    }

    if(1)
    {
        QToolButton *btn = new QToolButton;
        btn->setIcon(QIcon(":/images/lc_line.png"));
        btn->setCheckable(true);
        btn->setText("线");
        btn->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
        connect(btn, &QToolButton::clicked,this, &MainWindow::online);

        toolBar->addWidget(btn);
        m_toolButtons[Line] = btn;
    }

   // for (auto &tool : tools) {
    if(1)
    {
        QToolButton *btn = new QToolButton;
        btn->setIcon(QIcon(":/images/lc_rect.png"));
        btn->setCheckable(true);
        btn->setText("矩形");
        btn->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
        connect(btn, &QToolButton::clicked,this, &MainWindow::onrect);

        toolBar->addWidget(btn);
        m_toolButtons[Rectangle] = btn;
    }

    if(1)
    {
        QToolButton *btn = new QToolButton;
        btn->setIcon(QIcon(":/images/lc_ellipse.png"));
        btn->setCheckable(true);
        btn->setText("椭圆");
        btn->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
        connect(btn, &QToolButton::clicked,this, &MainWindow::onellipse);

        toolBar->addWidget(btn);
        m_toolButtons[Ellipse] = btn;
    }

    if(1)
    {
        QToolButton *btn = new QToolButton;
        btn->setIcon(QIcon(":/images/lc_text.png"));
        btn->setCheckable(true);
        btn->setText("文本");
        btn->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
        connect(btn, &QToolButton::clicked,this, &MainWindow::ontext);

        toolBar->addWidget(btn);
        m_toolButtons[Text] = btn;
    }

    if(1)
    {
        QToolButton *btn = new QToolButton;
        btn->setIcon(QIcon(":/images/icon_eraser.png"));
        btn->setCheckable(true);
        btn->setText("橡皮");
        btn->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
        connect(btn, &QToolButton::clicked,this, &MainWindow::onerase);

        toolBar->addWidget(btn);
        m_toolButtons[Eraser] = btn;
    }

    if(1)
    {
        QToolButton *btn = new QToolButton;
        btn->setIcon(QIcon(":/images/lc_fillstyle.png"));
        btn->setCheckable(true);
        btn->setText("油漆");
        btn->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
        connect(btn, &QToolButton::clicked,this, &MainWindow::ontong);

        toolBar->addWidget(btn);
        m_toolButtons[Bucket] = btn;
    }

    if(1)
    {
        QToolButton *btn = new QToolButton;
        btn->setIcon(QIcon(":/images/lc_freeline_unfilled.png"));
        btn->setCheckable(true);
        btn->setText("串点");
        btn->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
        connect(btn, &QToolButton::clicked,this, &MainWindow::onstroke);

        toolBar->addWidget(btn);
        m_toolButtons[Stroke] = btn;
    }


    if(1)
    {
        QToolButton *btn = new QToolButton;
        btn->setIcon(QIcon(":/images/data_delete.png"));
      //  btn->setCheckable(true);
        btn->setText("清除");
        btn->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
        connect(btn, &QToolButton::clicked,this, &MainWindow::clearback);

        toolBar->addWidget(btn);
        //  m_toolButtons[Bucket] = btn;
    }

    if(1)
    {
        QToolButton *btn = new QToolButton;
        btn->setIcon(QIcon(":/images/undo.png"));
      //  btn->setCheckable(true);
        btn->setText("取消");
        btn->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
        connect(btn, &QToolButton::clicked,this, &MainWindow::undo);

        toolBar->addWidget(btn);
      //  m_toolButtons[Stroke] = btn;
    }

    if(1)
    {
        QToolButton *btn = new QToolButton;
        btn->setIcon(QIcon(":/images/redo.png"));
      //  btn->setCheckable(true);
        btn->setText("重复");
        btn->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
        connect(btn, &QToolButton::clicked,this, &MainWindow::redo);

        toolBar->addWidget(btn);
      //  m_toolButtons[Stroke] = btn;
    }

    if(1)
    {
        QToolButton *btn = new QToolButton;
        btn->setIcon(QIcon(":/images/zoom-in.png"));
     //   btn->setCheckable(true);
        btn->setText("放大");
        btn->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
        connect(btn, &QToolButton::clicked,this, &MainWindow::zoomIn);

        toolBar->addWidget(btn);
     //   m_toolButtons[Stroke] = btn;
    }

    if(1)
    {
        QToolButton *btn = new QToolButton;
        btn->setIcon(QIcon(":/images/zoom-out.png"));
      //  btn->setCheckable(true);
        btn->setText("缩小");
        btn->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
        connect(btn, &QToolButton::clicked,this, &MainWindow::zoomOut);

        toolBar->addWidget(btn);
       // m_toolButtons[Stroke] = btn;
    }
   // }

    toolBar->addSeparator();

}

void MainWindow::About()
{
    CHMIAboutDlg dlg;
    dlg.exec();
}

void MainWindow::oncursor()
{
    setTool(ToolType::Cursor);
}

void MainWindow::onpen()
{
    setTool(ToolType::Pen);
}

void MainWindow::online()
{
    setTool(ToolType::Line);
}

void MainWindow::onrect()
{
    setTool(ToolType::Rectangle);
}

void MainWindow::onellipse()
{
    setTool(ToolType::Ellipse);
}

void MainWindow::ontext()
{
    setTool(ToolType::Text);
}

void MainWindow::undo()
{
    m_paintView->undoStack()->undo();
    m_paintView->update();
}

void MainWindow::redo()
{
    m_paintView->undoStack()->redo();
    m_paintView->update();
}

void MainWindow::clearback()
{
    m_paintView->setBack(QColor(255,255,255));
    m_paintView->update();
}

void MainWindow::onerase()
{
    setTool(ToolType::Eraser);
}

void MainWindow::ontong()
{
    setTool(ToolType::Bucket);
}

void MainWindow::onstroke()
{
    setTool(ToolType::Stroke);
}

void MainWindow::open()
{
    QString fileName = QFileDialog::getOpenFileName(this,
                                                    tr("Open Image"), "",
                                                    tr("Image Files (*.png *.jpg *.bmp)"));

    if (!fileName.isEmpty()) {
        if (!m_paintView->openImage(fileName)) {
            QMessageBox::warning(this, tr("Error"),
                                 tr("Could not open file."));
        }
        updateActions();
    }
}

QIcon MainWindow::createColorIcon(const QColor &color)
{
    QPixmap pix(24, 24);
    pix.fill(color);
    QPainter painter(&pix);
    painter.setPen(Qt::black);
    painter.drawRect(0, 0, 23, 23);
    return QIcon(pix);
}
void MainWindow::save()
{
    QString fileName = QFileDialog::getSaveFileName(this,
                                                    tr("Save Image"), "",
                                                    tr("PNG Files (*.png);;JPEG Files (*.jpg);;BMP Files (*.bmp)"));

    if (!fileName.isEmpty()) {
        if (!m_paintView->saveImage(fileName)) {
            QMessageBox::warning(this, tr("Error"),
                                 tr("Could not save file."));
        }
    }
}

void MainWindow::zoomIn()
{
    m_paintView->scaleImage(1.25);
    updateActions();
}

void MainWindow::zoomOut()
{
    m_paintView->scaleImage(0.8);
    updateActions();
}

#define RULER_SIZE 30

void MainWindow::resizeEvent(QResizeEvent *event)
{
    // m_hRuler->resize(this->size().width() - RULER_SIZE - 1, RULER_SIZE);
    // m_hRuler->move(RULER_SIZE, 0);
    // m_vRuler->resize(RULER_SIZE, this->size().height() - RULER_SIZE - 1);
    // m_vRuler->move(0, RULER_SIZE);

    QMainWindow::resizeEvent(event);
}
void MainWindow::setTool(ToolType tool)
{
    m_paintView->setTool(tool);

    // 更新按钮状态
    QMapIterator<ToolType, QToolButton*> it(m_toolButtons);
    while (it.hasNext()) {
        it.next();
        it.value()->setChecked(it.key() == tool);
    }
}

void MainWindow::updateActions()
{
    bool hasImage = !m_paintView->pixmap().isNull();
    actAbout->setEnabled(hasImage);

    // 可以添加更多状态更新逻辑
    // 例如根据缩放因子禁用按钮：
    // double scale = m_paintView->scaleFactor();
    // actAbout->setEnabled(scale < 5.0);
    // m_zoomOutAction->setEnabled(scale > 0.1);
}
